@@ -92,7 +92,7 @@ typedef struct _mmd_filebuf_s		// Buffered file
 {
   mmd_iocb_t	cb;			// Read callback function
   void		*cbdata;		// Read callback data
-  char		buffer[8192],		// Buffer
+  char		buffer[65536],		// Buffer
 		*bufptr,		// Pointer into buffer
 		*bufend;		// End of buffer
 } _mmd_filebuf_t;
@@ -179,6 +179,8 @@ mmdCopyAllText(mmd_t *node)		// I - Parent node
     if (current->text)
     {
       // Append this node's text to the string...
+      long alloff = allptr - all;	// Offset within current buffer
+
       textlen = strlen(current->text);
       allsize += textlen + (size_t)current->whitespace;
       temp    = realloc(all, allsize);
@@ -189,8 +191,8 @@ mmdCopyAllText(mmd_t *node)		// I - Parent node
 	return (NULL);
       }
 
-      allptr = temp + (allptr - all);
       all    = temp;
+      allptr = all + alloff;
 
       if (current->whitespace)
 	*allptr++ = ' ';
