@@ -1,32 +1,25 @@
 /*
- * "$Id: rc4.c 288 2000-06-05 17:55:45Z mike $"
+ * RC4 functions for HTMLDOC.
  *
- *   RC4 functions for HTMLDOC.
+ * Original code by Tim Martin
+ * Copyright 1999 by Carnegie Mellon University, All Rights Reserved
  *
- *   Original code by Tim Martin
- *   Copyright 1999 by Carnegie Mellon University, All Rights Reserved
+ * Permission to use, copy, modify, and distribute this software and its
+ * documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and that
+ * both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of Carnegie Mellon
+ * University not be used in advertising or publicity pertaining to
+ * distribution of the software without specific, written prior
+ * permission.
  *
- *   Permission to use, copy, modify, and distribute this software and its
- *   documentation for any purpose and without fee is hereby granted,
- *   provided that the above copyright notice appear in all copies and that
- *   both that copyright notice and this permission notice appear in
- *   supporting documentation, and that the name of Carnegie Mellon
- *   University not be used in advertising or publicity pertaining to
- *   distribution of the software without specific, written prior
- *   permission.
- *
- *   CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
- *   THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
- *   FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE FOR
- *   ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
- *   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
- *   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
- *   OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
- *
- * Contents:
- *
- *   rc4_init()    - Initialize an RC4 context with the specified key.
- *   rc4_encrypt() - Encrypt the given buffer.
+ * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
+ * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
+ * FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE FOR
+ * ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
+ * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
 #include "rc4.h"
@@ -50,7 +43,7 @@ rc4_init(rc4_context_t       *text,	/* IO - Context */
   */
 
   for (i = 0; i < 256; i ++)
-    text->sbox[i] = i;
+    text->sbox[i] = (unsigned char)i;
 
   for (i = 0, j = 0; i < 256; i ++)
   {
@@ -58,7 +51,7 @@ rc4_init(rc4_context_t       *text,	/* IO - Context */
     * j = (j + Si + Ki) mod 256
     */
 
-    j = (j + text->sbox[i] + key[i % keylen]) & 255;
+    j = (j + text->sbox[i] + key[(unsigned)i % keylen]) & 255;
 
    /*
     * Swap Si and Sj...
@@ -138,8 +131,3 @@ rc4_encrypt(rc4_context_t       *text,		/* I - Context */
   text->i = i;
   text->j = j;
 }
-
-
-/*
- * End of "$Id: rc4.c 288 2000-06-05 17:55:45Z mike $".
- */
